/*
*******************************************************************************************************************
*									Demonstration for Nordic nRF905 module
* Description:  This program demonstrates interface between Microchip PIC18 LF4550 at 3.3V with nRF905_MOD.
*				The PCB employed was PIC18-LF4550-STK1.
*				Connection with nRF905_MOD completed by strip wire via the expansion port.
*				This program simply sets the RF module to transmit mode, then periodically (~1sec) transmits
*				data (load with 0xAB in this example) with beep sound from buzzer onboard
*				This program may be used with another program in Keil C for 8051 available for download
*				under our web site for AT89C51RB2 Eval board at:
*				http://www.techtoys.com.hk/8051/AT89C51RB2_3V3_EVAL/AT89C51RB2_3V3_EVAL.htm
*				This program sets nRF905 to Tx mode. So, PIC transmits, and the receiving side can be another
*				mcu like 8051, etc.
* File:			..\nRF905\main.c
* Software:		C18 compiler version 2.40; IDE is MPLAB 7.41
* Programmer: 	John Leung, TechToys Co. (www.TechToys.com.hk)
* Hardware:		PIC18-LF4550-STK1, PIC18LF4550 at Vdd=3.3V
* Date:			28th Feb 2007
* Version:		1.0
* Programmer:	John Leung
*
* 												All Rights Reserved
*
*******************************************************************************************************************
*/


#include <p18cxxx.h>
#include "delay.h"
#include "nRF905.h"

/*
********************************************************************************************************************
*												Pragma Section
*
* Configuration bits under MPLAB v7.41 subject to changes on every little change on project settings.
* So #pragma config statments used for configuration bits instead of using Configuration bits tab in MPLAB
* Note: Refer to pdf document "mcc18\doc\MPLAB-C18-Addendum.pdf" under mcc18 installation directory for config
* 		variables available
********************************************************************************************************************
*/
#pragma config PLLDIV = 5			// This value has to be 5 for 20Mhz xtal as PLL accepts fixed input of 4MHz only
#pragma config USBDIV = 2			// Clock source from 96MHz PLL/2, therefore USB clock is 48MHz in full speed
#pragma config FOSC   = HSPLL_HS	// HS oscillator, PLL enabled
#pragma config CPUDIV = OSC4_PLL6	// 96MHz PLL Src/6 => a CPU clock of 16MHz achieved for Vdd=3.3V
#pragma config PWRT   = ON			// PowerUp timer ON
#pragma config WDT    = OFF			// watchdog timer off
#pragma config LVP    = OFF			// low level voltage progamming OFF
#pragma config BOR    = OFF			// brown out detect off
#pragma config DEBUG  = ON			// Debug ON
#pragma config PBADEN = OFF 		// PORTB<4:0> as digital IO on reset
#pragma config STVREN = ON  		// Stack overflow reset ON
#pragma config VREGEN = OFF			// Disable internal 3.3V regulator!


/*
********************************************************************************************************************
* 														MAIN
* 
********************************************************************************************************************
*/
void main(void)
{
	unsigned char i;

	ADCON1 = 0x0F;					//All digital operation	

	TRISCbits.TRISC2 = 0;			//set RC2 an output

	rfInitIO();
	rfConfig905();

	for(i=0;i<32;i++)				//load data in TxBuf[]
		TxBuf[i] = 0xAB;

	for(;;)
	{
		rfTxPacket();		
		for(i=0;i<10;i++) DelayMs(100);		
		for(i=0;i<200;i++) 
			{	DelayUs(200);	
				LATCbits.LATC2 = !LATCbits.LATC2;
			}
	}
	
}





